@@ -25,6 +25,8 @@ d_args = {
     'etr_asce': 10.626087665395694,
     'etr_refet': 10.571314344056955,
     'etw_refet': 6.242411580074248,
+    'eto_fs1': 4.373303512213786,
+    'eto_fs2': 3.5689285353574958,
     'etr_rso_simple': 10.628137858930051,
     'q': 0.008691370735727117,          # Computed from Ea from Tdew
     'q_asce': 0.008692530868140688,     # Computed from Ea from Tdew
@@ -101,6 +103,34 @@ def test_refet_daily_etw():
         .getInfo()
     assert float(output['etw']) == pytest.approx(d_args['etw_refet'])
 
+def test_refet_daily_eto_fs1():
+    refet = Daily(
+        tmax=ee.Image.constant(d_args['tmax']),
+        tmin=ee.Image.constant(d_args['tmin']),
+        ea=ee.Image.constant(d_args['ea']),
+        rs=ee.Image.constant(d_args['rs']),
+        uz=ee.Image.constant(d_args['uz']), zw=ee.Number(s_args['zw']),
+        elev=ee.Number(s_args['elev']), lat=ee.Number(s_args['lat']),
+        doy=ee.Number(d_args['doy']), method='refet')
+    output = refet.eto_fs1 \
+        .reduceRegion(ee.Reducer.first(), geometry=constant_geom, scale=1) \
+        .getInfo()
+    assert float(output['eto_fs1']) == pytest.approx(d_args['eto_fs1'])
+
+def test_refet_daily_eto_fs2():
+    refet = Daily(
+        tmax=ee.Image.constant(d_args['tmax']),
+        tmin=ee.Image.constant(d_args['tmin']),
+        ea=ee.Image.constant(d_args['ea']),
+        rs=ee.Image.constant(d_args['rs']),
+        uz=ee.Image.constant(d_args['uz']), zw=ee.Number(s_args['zw']),
+        elev=ee.Number(s_args['elev']), lat=ee.Number(s_args['lat']),
+        doy=ee.Number(d_args['doy']), method='refet')
+    output = refet.eto_fs2 \
+        .reduceRegion(ee.Reducer.first(), geometry=constant_geom, scale=1) \
+        .getInfo()
+    assert float(output['eto_fs2']) == pytest.approx(d_args['eto_fs2'])
+
 
 def test_refet_daily_rso_type_simple():
     refet = Daily(
@@ -261,9 +291,9 @@ def test_refet_daily_nldas_eto():
         .getInfo()['eto']
 
     expected = ee.Image('projects/eddi-noaa/nldas/daily/20170701')\
-        .select(['ETo'])\
+        .select(['eto_asce'])\
         .reduceRegion(ee.Reducer.first(), geometry=test_point, scale=1)\
-        .getInfo()['ETo']
+        .getInfo()['eto_asce']
 
     assert output == pytest.approx(expected, rel=0.001)
 
